Struct aws_sdk_dataexchange::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
An ergonomic service client for DataExchange.
This client allows ergonomic access to a DataExchange-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the CancelJob operation.
See CancelJob for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateDataSet operation.
See CreateDataSet for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateEventAction operation.
See CreateEventAction for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateJob operation.
See CreateJob for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateRevision operation.
See CreateRevision for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteAsset operation.
See DeleteAsset for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteDataSet operation.
See DeleteDataSet for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteEventAction operation.
See DeleteEventAction for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteRevision operation.
See DeleteRevision for more information about the
operation and its arguments.
Constructs a fluent builder for the GetAsset operation.
See GetAsset for more information about the
operation and its arguments.
Constructs a fluent builder for the GetDataSet operation.
See GetDataSet for more information about the
operation and its arguments.
Constructs a fluent builder for the GetEventAction operation.
See GetEventAction for more information about the
operation and its arguments.
Constructs a fluent builder for the GetJob operation.
See GetJob for more information about the
operation and its arguments.
Constructs a fluent builder for the GetRevision operation.
See GetRevision for more information about the
operation and its arguments.
Constructs a fluent builder for the ListDataSetRevisions operation.
See ListDataSetRevisions for more information about the
operation and its arguments.
Constructs a fluent builder for the ListDataSets operation.
See ListDataSets for more information about the
operation and its arguments.
Constructs a fluent builder for the ListEventActions operation.
See ListEventActions for more information about the
operation and its arguments.
Constructs a fluent builder for the ListJobs operation.
See ListJobs for more information about the
operation and its arguments.
Constructs a fluent builder for the ListRevisionAssets operation.
See ListRevisionAssets for more information about the
operation and its arguments.
Constructs a fluent builder for the ListTagsForResource operation.
See ListTagsForResource for more information about the
operation and its arguments.
Constructs a fluent builder for the StartJob operation.
See StartJob for more information about the
operation and its arguments.
Constructs a fluent builder for the TagResource operation.
See TagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UntagResource operation.
See UntagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateAsset operation.
See UpdateAsset for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateDataSet operation.
See UpdateDataSet for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateEventAction operation.
See UpdateEventAction for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateRevision operation.
See UpdateRevision for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.